@@ -101,7 +101,29 @@ class Predictor:
 
         device = torch.device(device_str)
 
-        self._mixer.net.to(device)
+        self._mixer.net.net = self._mixer.net.net.to(device)
+        try:
+            self._mixer.net.awareness_net = self._mixer.net.awareness_net.to(device)
+        except:
+            pass
+
+        available_devices = 1
+        if device_str == 'cuda':
+            available_devices = torch.cuda.device_count()
+
+        if available_devices > 1:
+            self._mixer.net._foward_net = torch.nn.DataParallel(self._mixer.net.net)
+            try:
+                self._mixer.net._foward_awareness_net = torch.nn.DataParallel(self._mixer.net.awareness_net)
+            except:
+                pass
+        else:
+            self._mixer.net._foward_net = self._mixer.net.net
+            try:
+                self._mixer.net._foward_awareness_net = self._mixer.net.awareness_net
+            except:
+                pass
+
         self._mixer.net.device = device
         for e in self._mixer.encoders:
             try:
@@ -316,7 +338,7 @@ class Predictor:
                         break
 
                     # Once the training error is getting smaller, enable dropout to teach the network to predict without certain features
-                    if subset_iteration == 2 and training_error < 0.4 and not from_data_ds.enable_dropout:
+                    if subset_iteration > 1 and training_error < 0.4 and not from_data_ds.enable_dropout:
                         eval_every_x_epochs = max(1, int(eval_every_x_epochs/2) )
                         logging.info('Enabled dropout !')
                         from_data_ds.enable_dropout = True
@@ -328,7 +350,7 @@ class Predictor:
                         continue
 
                     # If the selfaware network isn't able to train, go back to the original network
-                    if subset_iteration == 2 and (np.isnan(training_error) or np.isinf(training_error) or training_error > pow(10,5)) and not mixer.stop_selfaware_training:
+                    if subset_iteration > 1 and (np.isnan(training_error) or np.isinf(training_error) or training_error > pow(10,5)) and not mixer.stop_selfaware_training:
                         mixer.start_selfaware_training = False
                         mixer.stop_selfaware_training = True
                         lowest_error = None
@@ -339,7 +361,7 @@ class Predictor:
                         continue
 
                     # Once we are past the priming/warmup period, start training the selfaware network
-                    if subset_iteration == 2 and not mixer.is_selfaware and CONFIG.SELFAWARE and not mixer.stop_selfaware_training and training_error < 0.35:
+                    if subset_iteration > 1 and not mixer.is_selfaware and CONFIG.SELFAWARE and not mixer.stop_selfaware_training and training_error < 0.35:
                         logging.info('Started selfaware training !')
                         mixer.start_selfaware_training = True
                         lowest_error = None
