@@ -36,15 +36,14 @@ class NnMixer:
         self.nn_class = DefaultNet
         self.dynamic_parameters = dynamic_parameters
         self.awareness_criterion = None
-        self.loss_combination_operator = operator.add
         self.start_selfaware_training = False
         self.stop_selfaware_training = False
         self.is_selfaware = False
         self.last_unaware_net = False
 
         self.max_confidence_per_output = []
-
         self.monitor = None
+
         for k in CONFIG.MONITORING:
             if CONFIG.MONITORING[k]:
                 from lightwood.mixers.helpers.debugging import TrainingMonitor
@@ -476,10 +475,6 @@ class NnMixer:
                     #self.monitor.plot_loss(total_loss.item(), self.total_iterations, 'Total Batch Loss')
                     self.monitor.plot_loss(error, self.total_iterations, 'Mean Total Running Loss')
 
-                if error < 1:
-                    if self.loss_combination_operator == operator.add:
-                        self.loss_combination_operator = operator.mul
-
             if CONFIG.MONITORING['epoch_loss']:
                 self.monitor.plot_loss(error, self.total_iterations, 'Train Epoch Error')
                 self.monitor.plot_loss(error, self.total_iterations, f'Train Epoch Error - Subset {subset_id}')
